==> p5-perlqt-4.10.1.tbz: share/perlqt/cmake/PerlQtExport-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
SET(CMAKE_IMPORT_FILE_VERSION 1)

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "PERLQT_perlqtcore4" for configuration "Release"
SET_PROPERTY(TARGET PERLQT_perlqtcore4 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(PERLQT_perlqtcore4 PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "/usr/local/lib/qt4/libQtCore.so;/usr/local/lib/qt4/libQtGui.so;/usr/local/lib/qt4/libQtNetwork.so;/usr/local/lib/perl5/5.14.2/mach/CORE/libperl.so;/usr/local/kde4/lib/libsmokebase.so;/usr/local/kde4/lib/libsmokeqtcore.so;/usr/local/kde4/lib/libsmokeqtgui.so;/usr/local/kde4/lib/libsmokeqtnetwork.so;-lm -lcrypt -lutil"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/perl5/site_perl/5.14.2/mach/auto/QtCore4/QtCore4.so"
  IMPORTED_SONAME_RELEASE "QtCore4.so"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS PERLQT_perlqtcore4 )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_PERLQT_perlqtcore4 "/usr/local/kde4/lib/perl5/site_perl/5.14.2/mach/auto/QtCore4/QtCore4.so" )

# Loop over all imported files and verify that they actually exist
FOREACH(target ${_IMPORT_CHECK_TARGETS} )
  FOREACH(file ${_IMPORT_CHECK_FILES_FOR_${target}} )
    IF(NOT EXISTS "${file}" )
      MESSAGE(FATAL_ERROR "The imported target \"${target}\" references the file
   \"${file}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    ENDIF()
  ENDFOREACH()
  UNSET(_IMPORT_CHECK_FILES_FOR_${target})
ENDFOREACH()
UNSET(_IMPORT_CHECK_TARGETS)

# Commands beyond this point should not need to know the version.
SET(CMAKE_IMPORT_FILE_VERSION)

==> p5-perlqt-4.10.3.tbz: share/perlqt/cmake/PerlQtExport-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
SET(CMAKE_IMPORT_FILE_VERSION 1)

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "PERLQT_perlqtcore4" for configuration "Release"
SET_PROPERTY(TARGET PERLQT_perlqtcore4 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(PERLQT_perlqtcore4 PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "/usr/local/lib/qt4/libQtCore.so;/usr/local/lib/qt4/libQtGui.so;/usr/local/lib/qt4/libQtNetwork.so;/usr/local/lib/perl5/5.14/mach/CORE/libperl.so;/usr/local/kde4/lib/libsmokebase.so;/usr/local/kde4/lib/libsmokeqtcore.so;/usr/local/kde4/lib/libsmokeqtgui.so;/usr/local/kde4/lib/libsmokeqtnetwork.so;-lm -lcrypt -lutil"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/perl5/site_perl/5.14/mach/auto/QtCore4/QtCore4.so"
  IMPORTED_SONAME_RELEASE "QtCore4.so"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS PERLQT_perlqtcore4 )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_PERLQT_perlqtcore4 "/usr/local/kde4/lib/perl5/site_perl/5.14/mach/auto/QtCore4/QtCore4.so" )

# Loop over all imported files and verify that they actually exist
FOREACH(target ${_IMPORT_CHECK_TARGETS} )
  FOREACH(file ${_IMPORT_CHECK_FILES_FOR_${target}} )
    IF(NOT EXISTS "${file}" )
      MESSAGE(FATAL_ERROR "The imported target \"${target}\" references the file
   \"${file}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    ENDIF()
  ENDFOREACH()
  UNSET(_IMPORT_CHECK_FILES_FOR_${target})
ENDFOREACH()
UNSET(_IMPORT_CHECK_TARGETS)

# Commands beyond this point should not need to know the version.
SET(CMAKE_IMPORT_FILE_VERSION)
